@@ -5,8 +5,8 @@
 # This source code is licensed under the BSD-style license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Any, Dict, Protocol, runtime_checkable
-
+from typing import Any, Dict
+from typing_extensions import Protocol, runtime_checkable
 
 @runtime_checkable
 class Stateful(Protocol):
